<?php
use Required\DynamicSyncPublicController;
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/public
 * @author     Your Name <email@example.com>
 */
class DynamicSync_Public extends DynamicSyncPublicController {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->load();
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/dynamicsync-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/dynamicsync-public.js', array( 'jquery' ), $this->version, false );

	}

	public function register_shortcodes() {
		add_filter( 'wp_kses_allowed_html', 'activateDsV1PostValues', 10, 2);

		function activateDsV1PostValues( $allowedposttags, $context ) {
		    if ( $context == 'post' ) {
		        $allowedposttags['input']['value'] = 1;
		        $allowedposttags['input']['style'] = 1;
		    }
		    return $allowedposttags;
		}
		
	    add_shortcode( 'dynamicsync_event_calendar', array( $this, 'dynamicsync_event_calendar') );
	    add_shortcode( 'dynamicsync_event_info', array( $this, 'dynamicsync_event_info') );
		add_shortcode( 'dynamicsync_event_info_template', array( &$this, 'dynamicsync_event_info_template' ) );
		add_shortcode( 'dynamicsync_event_date_dropdown', array( &$this, 'dropdown_select' ) );
		add_shortcode( 'dynamicsync_date_selector', array( &$this, 'date_selector' ) );
		add_shortcode( 'dynamicsync_add_to_calendar', array( &$this, 'dynamicsync_add_to_calendar' ) );
		add_shortcode( 'dynamicsync_venue_map', array( &$this, 'dynamicsync_venue_map' ) );
		add_shortcode( 'dynamicsync_event_date_id_script', array( &$this, 'dynamicsync_event_date_id_script' ) );
		add_shortcode( 'dynamicsync_load_registration', array( &$this, 'populate_registration' ) );

	}
}
